@@ -26,7 +26,7 @@ class Artist(Entity):
         if attr in Artist.summary_attrs and not self.fetched_summary:
             self.fetch_summary()
             return getattr(self, attr)
-        if len(attr.split('_')) == 2:
+        if len(attr.split('_')) > 1:
             try:
                 result =  self._construct_timeseries(attr.replace('_', '/'))
                 setattr(self, attr, result) # don't want to call the api over and over
